// builtin
var assert = require('assert');

var cookie = require('..');

suite('serialize');

test('basic', function() {
    assert.equal('aaa=bbb', cookie.serialize('aaa', 'bbb'));
    assert.equal('aaa=bbb%20baz', cookie.serialize('aaa', 'bbb baz'));
});

test('path', function() {
    assert.equal('aaa=bbb; Path=/', cookie.serialize('aaa', 'bbb', {
        path: '/'
    }));
});

test('secure', function() {
    assert.equal('aaa=bbb; Secure', cookie.serialize('aaa', 'bbb', {
        secure: true
    }));

    assert.equal('aaa=bbb', cookie.serialize('aaa', 'bbb', {
        secure: false
    }));
});

test('domain', function() {
    assert.equal('aaa=bbb; Domain=example.com', cookie.serialize('aaa', 'bbb', {
        domain: 'example.com'
    }));
});

test('httpOnly', function() {
    assert.equal('aaa=bbb; HttpOnly', cookie.serialize('aaa', 'bbb', {
        httpOnly: true
    }));
});

test('maxAge', function() {
    assert.equal('aaa=bbb; Max-Age=1000', cookie.serialize('aaa', 'bbb', {
        maxAge: 1000
    }));
});

test('escaping', function() {
    assert.deepEqual('cat=%2B%20', cookie.serialize('cat', '+ '));
});

test('parse->serialize', function() {

    assert.deepEqual({ cat: 'aaa=123&name=baz five' }, cookie.parse(
      cookie.serialize('cat', 'aaa=123&name=baz five')));

    assert.deepEqual({ cat: ' ";/' }, cookie.parse(
      cookie.serialize('cat', ' ";/')));
});

